BottomAnimation class

Bottom Navigation Widget.

Inheritance

Constructors

BottomAnimation({Key? key, required int selectedIndex, required List<BottomNavItem> items, required Color activeIconColor, required Color deActiveIconColor, required Color backgroundColor, required ValueChanged<int> onItemSelect, required Color itemHoverColor, int hoverAlignmentDuration = 700, double iconSize = 30, TextStyle? textStyle, double barHeight = 80, double barRadius = 0, double itemHoverBorderRadius = 15, double itemHoverColorOpacity = .13, double itemHoverHeight = 55, double itemHoverWidth = 150})
const

Properties

activeIconColor → Color
final
backgroundColor → Color
final
barHeight → double
final
barRadius → double
final
deActiveIconColor → Color
final
hashCode → int
The hash code for this object.
no setterinherited
hoverAlignmentDuration → int
final
iconSize → double
final
itemHoverBorderRadius → double
final
itemHoverColor → Color
final
itemHoverColorOpacity → double
final
itemHoverHeight → double
final
itemHoverWidth → double
final
items → List<BottomNavItem>
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onItemSelect → ValueChanged<int>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedIndex → int
final
textStyle → TextStyle?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _BottomAnimationState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited